import * as React from 'react';
import moment from 'moment';
import 'moment/locale/zh-cn';

import { useHistory } from 'react-router-dom';
import Upload from '../upload';
import locale from 'antd/es/date-picker/locale/zh_CN';
import AMapLoader from '@amap/amap-jsapi-loader';
import {
	Form,
	Row,
	Input,
	Button,
	DatePicker,
	Col,
	Divider,
	message,
	Select,
} from 'antd';
import { FormItemProps } from 'antd/lib/form';
import { useGetProjectLimitArea } from '../../services/project';
import {
	Map_KEY,
	PROJECT_TYPES,
	PROJECT_NATURE,
	PROJECT_STATUS,
	INVEST_TYPE,
} from '../../const/const';
import './index.scss';
const { Option } = Select;

const basicInfos: FormItemProps[] = [
	{
		name: 'name',
		label: '工程名称',
		children: <Input placeholder='工程名称'></Input>,
	},
	{
		name: 'category',
		label: '项目类型',
		children: (
			<Select placeholder='请选择项目类型'>
				{Object.keys(PROJECT_TYPES).map((projetcTypeKey) => {
					return (
						<Option key={projetcTypeKey} value={+projetcTypeKey}>
							{PROJECT_TYPES[projetcTypeKey]}
						</Option>
					);
				})}
			</Select>
		),
	},
	{
		name: 'construct_type',
		label: '建设性质',
		children: (
			<Select placeholder='请选择建设性质'>
				{Object.keys(PROJECT_NATURE).map((projectNatureKey) => {
					return (
						<Option key={projectNatureKey} value={+projectNatureKey}>
							{PROJECT_NATURE[projectNatureKey]}
						</Option>
					);
				})}
			</Select>
		),
	},
	{
		name: 'covered_area',
		label: '总建筑面积',
		children: <Input placeholder='请输入总建筑面积' suffix='m²'></Input>,
	},

	{
		name: 'start_day',
		label: '计划开工日期',
		children: (
			<DatePicker
				locale={locale}
				className='date-wrapper'
				placeholder='请选择计划开工日期'
			/>
		),
	},
	{
		name: 'end_day',
		label: '计划竣工日期',
		children: (
			<DatePicker
				locale={locale}
				className='date-wrapper'
				placeholder='请选择计划竣工日期'
			/>
		),
	},

	{
		name: 'invest_type',
		label: '投资类型',
		children: (
			<Select placeholder='投资类型'>
				{Object.keys(INVEST_TYPE).map((element) => {
					return (
						<Option key={element} value={+element}>
							{INVEST_TYPE[element]}
						</Option>
					);
				})}
			</Select>
		),
	},

	{
		name: 'price',
		label: '总投资',
		children: <Input placeholder='总投资' suffix='万'></Input>,
	},
	{
		name: 'safety_record_no',
		label: '安监备案号',
		children: <Input placeholder='请输入安监备案号'></Input>,
	},
	{
		name: 'project_status',
		label: '项目状态',
		children: (
			<Select placeholder='请选择项目状态'>
				{Object.keys(PROJECT_STATUS).map((projectStatusKey) => {
					return (
						<Option key={projectStatusKey} value={+projectStatusKey}>
							{PROJECT_STATUS[projectStatusKey]}
						</Option>
					);
				})}
			</Select>
		),
	},

	{
		name: 'scale',
		label: '建筑规模',
		required: true,
		children: <Input placeholder='请输入建筑规模'></Input>,
	},
	{
		name: 'desc',
		label: '工程简介',
		required: false,
		children: <Input.TextArea placeholder='工程简介'></Input.TextArea>,
	},
];

interface Iprops {
	projectValues?: any;
	onSubmit: (values: any) => void;
}
const loadMap = (() => {
	let hasLoadMap = false;
	let Amap = null;
	let cache: any[] = [];
	let loading = false;
	return (callBack?: (AMap: any) => void) => {
		if (loading) {
			if (callBack) {
				cache.push(callBack);
			}
			return;
		}
		if (!hasLoadMap) {
			if (callBack) {
				cache.push(callBack);
			}
			loading = true;
			console.log('加载地图...');
			AMapLoader.load({
				key: Map_KEY,
				version: '2.0',
				plugins: [
					'AMap.DistrictSearch',
					'AMap.Geocoder',
					'AMap.PlaceSearch',
					'AMap.AutoComplete',
					'AMap.DistrictLayer',
				],
			})
				.then((AMap) => {
					hasLoadMap = true;
					Amap = AMap;
					cache.forEach((func) => {
						func(Amap);
					});
					cache = [];
				})
				.catch((error) => {
					message.error(error.mesaage);
				})
				.finally(() => {
					loading = false;
				});

			return;
		}
		callBack && callBack(Amap);
	};
})();

const projectDetail: React.FC<Iprops> = ({ projectValues, onSubmit }) => {
	const mapInstace = React.useRef<any>(null);
	const [form] = Form.useForm();
	const { request: requestLimitArea } = useGetProjectLimitArea();
	// 加载地图
	React.useEffect(() => {
		loadMap();
		return () => {
			mapInstace.current?.destroy();
		};
	}, []);
	// 获取限制区域
	React.useEffect(() => {
		requestLimitArea()
			.then((data) => {
				loadMap((AMap) => {
					const map = new AMap.Map('map-container', {
						resizeEnable: true,
						zoom: 11,
					});
					mapInstace.current = map;
					map.setCity(data.city_code, function() {
						console.info('切换城市成功');
					});

					const district = new AMap.DistrictSearch({
						extensions: 'all', //返回行政区边界坐标组等具体信息
						level: 'district', //查询行政级别为区县
						showbiz: false, //是否显示商圈
						subdistrict: 3,
					});
					district.search(data.city_code, function(status: any, result: any) {
						const geocoder = new AMap.Geocoder();
						if (status === 'complete') {
							const polygons: any[] = [];
							var bounds = result.districtList[0].boundaries;
							if (bounds) {
								for (var i = 0, l = bounds.length; i < l; i++) {
									//生成行政区划polygon
									const polygon = new AMap.Polygon({
										// strokeWeight: 1,
										path: bounds[i],
										bubble: false,
										cursor: 'pointer',
										strokeWeight: 1,
										fillOpacity: 0.4,
										fillColor: '#80d8ff',
										strokeColor: '#0091ea',
									});
									polygon.on('click', function(event) {
										const latitudelongitude =
											event.lnglat.getLng() + ',' + event.lnglat.getLat();
										geocoder.getAddress(
											[event.lnglat.getLng(), event.lnglat.getLat()],
											function(
												status: any,
												{
													regeocode: {
														formattedAddress,
														addressComponent: { adcode },
													},
												}
											) {
												if (status === 'complete' && result.info === 'OK') {
													form.setFieldsValue({
														latitudelongitude,
														location: formattedAddress,
														area_code: adcode,
													});
												}
											}
										);
									});
									polygons.push(polygon);
								}
							}
							map.add(polygons);
							map.setFitView(); //地图自适应
						}
					});
				});
			})
			.catch((error) => {
				console.log(error);
				message.error(error.messgae);
			});
	}, []);

	React.useEffect(() => {
		if (projectValues) {
			form.setFieldsValue({
				...projectValues,
				end_day: moment(projectValues.end_day),
				start_day: moment(projectValues.start_day),
				latitudelongitude: [projectValues.lon, projectValues.lat].join(','),
			});
		}
	}, [projectValues]);
	/**
	 * @description 表单提交
	 */
	const handleSubmit = () => {
		form.validateFields().then((data: any) => {
			const values = {
				...data,
				end_day: data['end_day'].unix(),
				start_day: data['start_day'].unix(),
				lon: +data.latitudelongitude.split(',')[0],
				lat: +data.latitudelongitude.split(',')[1],
				price: +data.price,
				covered_area: +data.covered_area,
			};
			onSubmit(values);
		});
	};
	return (
		<div className='project-wrappaer'>
			<Form form={form}>
				<Divider orientation='left'>工程信息</Divider>
				<Row>
					{basicInfos.map((info) => {
						return (
							<Col span={8} key={info.name as string}>
								<Form.Item
									required
									rules={
										info.required === false
											? []
											: [
													{
														required: true,
														message: `请输入${info.label}`,
													},
											  ]
									}
									labelCol={{ span: 6 }}
									wrapperCol={{ span: 18 }}
									{...info}></Form.Item>
							</Col>
						);
					})}
				</Row>

				<Divider orientation='left'>工程所在地</Divider>
				<Row>
					<Col span={8}>
						<Form.Item
							required
							labelCol={{ span: 6 }}
							label='经纬度'
							rules={[
								{
									required: true,
									message: `请输入/选择地理坐标`,
								},
							]}
							name='latitudelongitude'>
							<Input
								readOnly
								placeholder='请在地图上点选位置，获取坐标信息'></Input>
						</Form.Item>
					</Col>
					<Col span={10}>
						<Form.Item
							required
							labelCol={{ span: 6 }}
							label='所在地'
							rules={[
								{
									required: true,
									message: `请输入/选择地理坐标`,
								},
							]}
							name='location'>
							<Input
								readOnly
								placeholder='请在地图上点选位置，获取位置信息'></Input>
						</Form.Item>
					</Col>
					<Col>
						<Form.Item noStyle name='area_code'></Form.Item>
					</Col>
				</Row>
				<div id='map-container'>
					{/* <div className='map-search'>
						<div>
							<span>请输入关键字</span>
						</div>
						<input id='tipinput' autoComplete='off' type='text' />
					</div> */}
				</div>
				<Divider orientation='left'>施工信息</Divider>
				<Row>
					{[
						{
							name: 'project_plan',
							label: '施工平面图',
						},
						{
							name: 'project_effect_pic',
							label: '施工效果图',
						},
					].map((element) => {
						return (
							<Col span={8} key={element.name}>
								<Form.Item
									{...element}
									children={<Upload limit={1}></Upload>}></Form.Item>
							</Col>
						);
					})}
				</Row>
			</Form>
			<Row style={{ marginTop: 30 }}>
				<Button type='primary' onClick={handleSubmit}>
					提交
				</Button>
			</Row>
		</div>
	);
};
export default projectDetail;
