import * as React from 'react';
import { Form, Select, Button, Input, Space } from 'antd';
import { useProjectsList } from '../../services/project';
interface SearchProps {
	onSearch?: (values: any) => void;
}
const Search: React.FC<SearchProps> = (props) => {
	const [form] = Form.useForm();
	const { onSearch, children } = props;
	const [listState, requestProjectList] = useProjectsList();
	React.useEffect(() => {
		requestProjectList({ page: 0, filter: '', page_size: -1 });
	}, []);
	return (
		<>
			<Form
				layout='inline'
				form={form}
				onFinish={(values) => onSearch && onSearch(values)}>
				<Form.Item
					label='项目名'
					name='project_id'
					children={
						<Select allowClear style={{ width: 200 }} placeholder='请选择项目'>
							{listState.dataSource.map((project) => {
								return (
									<Select.Option key={project.id} value={project.id}>
										{project.name}
									</Select.Option>
								);
							})}
						</Select>
					}></Form.Item>
				<Form.Item
					name='state'
					label='设备状态'
					initialValue={-1}
					children={
						<Select style={{ width: 200 }} placeholder='设备状态'>
							{[
								{ value: -1, label: '全部' },
								{ value: 0, label: '离线' },
								{ value: 1, label: '在线' },
							].map((element) => {
								return (
									<Select.Option key={element.value} value={element.value}>
										{element.label}
									</Select.Option>
								);
							})}
						</Select>
					}></Form.Item>
				<Form.Item
					name='filter'
					label='关键字'
					children={
						<Input placeholder='设备名、设备唯一编码或安监备案号'></Input>
					}></Form.Item>
				{children}
				<Space>
					<Button htmlType='submit' type='primary'>
						搜索
					</Button>
					<Button
						htmlType='reset'
						onClick={() => {
							form.resetFields();
						}}>
						重置
					</Button>
				</Space>
			</Form>
		</>
	);
};
export default Search;
