import * as React from 'react';
import { message, Upload } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { UploadChangeParam, RcFile, UploadProps } from 'antd/lib/upload';
interface Iprops extends UploadProps {
	limit?: number;
	onChange?: (values: any) => void;
	[propIndex: string]: any;
	value?: string | any[];
}
const customeUpload: React.FC<Iprops> = (props) => {
	const { limit, value = [] } = props;
	const [state, setState] = React.useState<{ fileList: any[] }>({
		fileList: [],
	});
	React.useEffect(() => {
		if (value && value.length !== 0) {
			setState((preState) => {
				if (typeof value === 'string') {
					return {
						...preState,
						fileList: preState.fileList.concat({
							url: value,
							status: 'done',
							uid: value,
						}),
					};
				}
				return {
					...preState,
					fileList: value.map((element) => {
						return { url: element, status: 'done', uid: element, ...element };
					}),
				};
			});
		}
	}, [value]);

	const handleChange = (info: any) => {
		if (props.onChange && info.file.status === 'removed') {
			return props.onChange(info.fileList);
		}
		//代表替换
		if (props.onChange && info.file && info.file.response) {
			props.onChange(
				info.fileList.map((element: any) => {
					return element.response ? element.response.data : undefined;
				})
			);
		}
	};
	const onBeforeUpload = (file: RcFile, FileList: RcFile[]) => {
		const hasFile = state.fileList.find(
			(tempFile) => tempFile.name === file.name && file.type === tempFile.type
		);
		if (hasFile) {
			message.error('您已上传这个文件');
			return Promise.reject();
		}
		return Promise.resolve();
	};
	return (
		<Upload
			fileList={state.fileList}
			action='/api/v1/upload'
			listType='picture-card'
			accept='image/*'
			onChange={handleChange}
			onPreview={(file) => {
				console.log('file', file);
				window.open(file.url);
			}}
			beforeUpload={onBeforeUpload}>
			{limit && state.fileList.length >= limit ? null : (
				<div>
					<PlusOutlined />
					<div style={{ marginTop: 8 }}>点击上传</div>
				</div>
			)}
		</Upload>
	);
};
export default customeUpload;
