import * as React from 'react';
import { Layout as ALayOut, Menu, Dropdown } from 'antd';
import {
	LoginOutlined,
	ProjectOutlined,
	UsergroupAddOutlined,
	VideoCameraOutlined,
	UnorderedListOutlined,
	BorderRightOutlined,
	SettingOutlined,
	DownOutlined,
	UserOutlined,
} from '@ant-design/icons';
import {
	useHistory,
	Link,
	Switch,
	Route,
	RouteComponentProps,
} from 'react-router-dom';
import './index.scss';
const { Header, Sider, Content } = ALayOut;

const layout: React.FC<any> = ({ routes, match }) => {
	const history = useHistory();
	const handleChangeRouter = ({ key }: any) => {
		history.push(key);
	};
	const handleLogout = () => {
		localStorage.clear();
		location.href = '/login';
	};
	return (
		<ALayOut className='layout'>
			<Sider trigger={null} collapsible>
				<div className='logo'>
					<h3>企业平台</h3>
				</div>
				<Menu
					className='layout-sider'
					mode='inline'
					onSelect={handleChangeRouter}
					defaultSelectedKeys={[history.location.pathname]}>
					<Menu.Item key='/projects' icon={<ProjectOutlined></ProjectOutlined>}>
						工程管理
					</Menu.Item>
					<Menu.Item key='/accounts' icon={<UsergroupAddOutlined />}>
						账号管理
					</Menu.Item>
					<Menu.SubMenu title='设备列表' icon={<UnorderedListOutlined />}>
						<Menu.Item key='/dust' icon={<BorderRightOutlined />}>
							扬尘设备
						</Menu.Item>
            <Menu.Item key='/head-mast' icon={<BorderRightOutlined />}>
              塔机设备
            </Menu.Item>
						<Menu.Item key='/videos' icon={<VideoCameraOutlined />}>
							视频设备
						</Menu.Item>
						<Menu.Item key='/accessController' icon={<VideoCameraOutlined />}>
							门禁设备
						</Menu.Item>
					</Menu.SubMenu>
				</Menu>
			</Sider>
			<ALayOut className='site-layout'>
				<Header className='site-layout-header' style={{ padding: 15 }}>
					<Dropdown
						overlay={() => {
							return (
								<Menu>
									<Menu.Item>
										<Link to='setup'>
											<SettingOutlined /> 个人中心
										</Link>
									</Menu.Item>
									<Menu.Item>
										<a
											target='_blank'
											rel='noopener noreferrer'
											onClick={handleLogout}>
											<LoginOutlined></LoginOutlined> 退出
										</a>
									</Menu.Item>
								</Menu>
							);
						}}>
						<a
							className='ant-dropdown-link'
							onClick={(e) => e.preventDefault()}>
							<UserOutlined style={{ fontSize: 16 }}></UserOutlined>
							{localStorage.getItem('username')}
							<DownOutlined></DownOutlined>
						</a>
					</Dropdown>
				</Header>
				<Content
					className='site-layout-background'
					style={{
						margin: '24px 16px',
						padding: 24,
					}}>
					<Switch>
						{routes.map((route) => {
							if (route.redirect) {
								return <route.redirect key={route.path}></route.redirect>;
							}
							return (
								<Route
									key={route.path}
									exact={route.exact}
									path={route.path}
									component={route.component}></Route>
							);
						})}
					</Switch>
				</Content>
			</ALayOut>
		</ALayOut>
	);
};
export default layout;
