import React, { useState, useEffect } from 'react';
import { Table } from 'antd';
import { ColumnProps } from 'antd/lib/table';
import { DeviceSearch } from '../../components/search';
import { useAcessControllerList } from '../../services/accessController';
const DEVICE_STATE = {
	0: '离线',
	1: '在线',
};
const colums: ColumnProps<any>[] = [
	{
		title: '项目名',
		key: 'project_name',
		dataIndex: 'project_name',
	},
	{
		title: '供应商',
		key: 'provider_name',
		dataIndex: 'provider_name',
	},
	{
		title: '设备名',
		key: 'name',
		dataIndex: 'name',
	},
	{
		title: '设备唯一编码',
		key: 'sn',
		dataIndex: 'sn',
	},
	{ key: 'manufacturer', dataIndex: 'manufacturer', title: '生产厂家' },
	{
		title: '入库时间',
		key: 'created_time',
		dataIndex: 'created_time',
	},
	{
		title: '状态',
		key: 'state',
		dataIndex: 'state',
		render(dataIndex) {
			return DEVICE_STATE[dataIndex];
		},
	},
];
/**
 * @description 门禁列表
 */
const accessController: React.FC = () => {
	const [searchState, changeSearchState] = useState({
		page: 1,
		filter: '',
		project_id: -1,
		state: -1,
	});
	const { state: listState, request: requestList } = useAcessControllerList();
	useEffect(() => {
		requestList(searchState);
	}, [searchState]);

	return (
		<>
			<DeviceSearch
				onSearch={(values) => {
					changeSearchState(values);
				}}></DeviceSearch>
			<Table
				columns={colums}
				loading={listState.loading}
				pagination={{
					hideOnSinglePage: true,
					current: searchState.page,
					onChange: (page) => {
						changeSearchState((preState) => ({ ...preState, page }));
					},
				}}
				dataSource={listState.dataSouce}></Table>
		</>
	);
};
export default accessController;
