import * as React from 'react';
import { Row, Col, Table, Button, Modal, message, Input, Result } from 'antd';
import { StopOutlined } from '@ant-design/icons';
import { ColumnProps } from 'antd/lib/table';
import {
	useAccountList,
	AccountEnable,
	useUpdateAccountStatus,
	AccoutTypes,
} from '../../services/accounts';
const { Search } = Input;
const accounts: React.FC = (props) => {
	const [searchState, setSearchState] = React.useState({
		page: 1,
		filter: '',
	});
	const [accountState, requestAccounts] = useAccountList();
	React.useEffect(() => {
		requestAccounts(searchState);
	}, [searchState.page, searchState.filter]);
	const [updateState, requestUpdate] = useUpdateAccountStatus();
	const handleSearch = (value: string) => {
		setSearchState((preState) => ({ ...preState, filter: value, page: 1 }));
	};
	const columns: ColumnProps<any>[] = [
		{
			title: '序号',
			dataIndex: 'index',
			key: 'index',
    },
    {
      title: '项目名',
      dataIndex: 'project_name',
      key: 'project_name',
    },
    {
      title: '安监备案号',
      dataIndex: 'safety_record_no',
      key: 'safety_record_no',
    },
		{
			title: '账号',
			dataIndex: 'username',
			key: 'username',
		},
		{
			title: '密码',
			dataIndex: 'passwd',
			key: 'passwd',
		},
		{
			title: '账号类型',
			dataIndex: 'user_type',
			key: 'user_type',
			render: (dataIndex) => AccoutTypes[dataIndex as 3 | 1 | 2],
		},
		{
			title: '操作',
			render: (record) => {
				return (
					<Button
						type='primary'
						danger={record.enable}
						onClick={() => {
							Modal.confirm({
								content: `是否${AccountEnable[record.enable]}账号${
									record.username
								}`,
								cancelText: '取消',
								okText: '确认',
								okButtonProps: { loading: updateState.loading },
								onOk: () => {
									requestUpdate({
										id: record.id,
										enable: !record.enable,
									})
										.then(() => {
											message.success('更新成功');
											requestAccounts(searchState);
										})
										.catch((error) => {
											message.error(error.message);
										});
								},
							});
						}}>
						{AccountEnable[record.enable]}
					</Button>
				);
			},
		},
	];
	return (
		<>
			<Row gutter={[0, 24]}>
				<Col span={6}>
					<Search
						placeholder='项目名，账号名称或安监备案号'
						onSearch={handleSearch}></Search>
				</Col>
			</Row>
			{accountState.error ? (
				<Result
					status='error'
					title={accountState.error.code}
					subTitle={accountState.error.message}></Result>
			) : (
				<Table
					columns={columns}
					dataSource={accountState.dataSource}
					rowKey={(record: any) => record.id}
					pagination={{
						hideOnSinglePage: true,
						total: accountState.total,
						current: accountState.page,
						onChange: (page: number) => {
							console.log(page);
							setSearchState((preState) => ({ ...preState, page }));
						},
					}}
					loading={accountState.loading}></Table>
			)}
		</>
	);
};
export default accounts;
