import * as React from 'react';
import { Redirect } from 'react-router-dom';
import { Form, Input, Button, Row, message, Typography, Image } from 'antd';
import { Link, RouteComponentProps } from 'react-router-dom';

import {
	UserOutlined,
	LockOutlined,
	VerifiedOutlined,
} from '@ant-design/icons';
import { useUserLogin, useCaptchaId } from '../../services/user';
import { PROVIDE_HOST } from '../../const/const';
import './index.scss';
const layout = {
	labelCol: { span: 3 },
	wrapperCol: { span: 24 },
};

const login = ({
	history,
	location,
}: RouteComponentProps<any, any, { from: { pathname: string } }>) => {
	const { from } = location.state || { from: { pathname: '/' } };
	const [redirectToReferrer, chanRedirectToReferrer] = React.useState(false);
	const [state, setState] = React.useState({
		timestamp: Date.now(),
	});
	const [loginState, requestLogin] = useUserLogin();
	const [captchaState, requestCaptchaId] = useCaptchaId();
	React.useEffect(() => {
		requestCaptchaId();
	}, [state.timestamp]);
	const [form] = Form.useForm();
	const handleSubmit = (values: any) => {
		if (loginState.loading) {
			return;
		}
		requestLogin({ ...values, captcha: captchaState.data.capture_id })
			.then(() => {
				localStorage.setItem('username', values.user);
				message.success('登录成功');
				chanRedirectToReferrer(true);
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, timestamp: Date.now() }));
				message.error(error.message);
			});
	};
	if (redirectToReferrer) {
		return <Redirect to={from}></Redirect>;
	}
	return (
		<div className='login-wrapper'>
			<div className='login-form-card'>
				<h1>企业管理平台</h1>
				<Form
					{...layout}
					form={form}
					initialValues={{ remember: true }}
					onFinish={handleSubmit}>
					<Form.Item
						name='user'
						colon={false}
						rules={[
							{
								required: true,
								message: '请输入用户名!',
							},
						]}>
						<Input
							size='large'
							prefix={<UserOutlined />}
							placeholder='用户名'
						/>
					</Form.Item>

					<Form.Item
						name='password'
						colon={false}
						rules={[
							{
								required: true,
								message: '请输入密码!',
							},
						]}>
						<Input.Password
							size='large'
							prefix={<LockOutlined />}
							placeholder='密码'
						/>
					</Form.Item>

					<Form.Item
						name='verify'
						colon={false}
						rules={[
							{
								required: true,
								message: '请输入验证码!',
							},
						]}>
						<Input
							className='login-form-code'
							prefix={<VerifiedOutlined />}
							placeholder='验证码'
							autoComplete='off'
							size='large'
							suffix={
								<img
									onClick={() => {
										setState((preState) => ({
											...preState,
											timestamp: Date.now(),
										}));
									}}
									className='capture_img'
									src={`/api/v1/user/captcha_png/${captchaState.data.capture_id}`}></img>
							}
						/>
					</Form.Item>
					<Form.Item>
						<Button
							loading={loginState.loading}
							type='primary'
							htmlType='submit'
							block
							size='large'>
							登录
						</Button>
					</Form.Item>
					<Form.Item>
						<Button href='/userQuery' size='large' block>
							查询
						</Button>
					</Form.Item>
				</Form>
				<Row justify='space-between'>
					<Link to='/registered'>企业注册</Link>
					<a target='_blank' rel='noopener noreferrer' href={PROVIDE_HOST}>
						供应商公示
					</a>
					<Link to='/forget'>忘记密码？</Link>
				</Row>
			</div>
		</div>
	);
};
export default login;
