import React from 'react';
import { Button, message, Spin } from 'antd';
import { RollbackOutlined } from '@ant-design/icons';
import { RouteComponentProps, useParams } from 'react-router-dom';
import ProjectForm from '../../components/project';
import { useProjectDetail, useProjectUpdate } from '../../services/project';
const ProjectUpdate: React.FC<RouteComponentProps> = ({ history }) => {
  const { id } = useParams<{ id: string }>();
  const [detailState, requestDetail] = useProjectDetail();
  const [updateState, requestUpdate] = useProjectUpdate();
  React.useEffect(() => {
    requestDetail({ id: Number(id) });
  }, [id]);
  const handleSubmit = (values: any) => {
    requestUpdate({ ...values, id: Number(id) })
      .then(() => {
        message.success('更新项目成功', 1, () => {
          history.goBack();
        });
      })
      .catch((error) => {
        message.error(error.message);
      });
  };
  return (
    <Spin spinning={updateState.loading}>
      <Button
        onClick={() => {
          history.goBack();
        }}
        icon={<RollbackOutlined />}>
        返回
      </Button>

      <ProjectForm
        projectValues={detailState.dataSource}
        onSubmit={handleSubmit}></ProjectForm>
    </Spin>
  );
};
export default ProjectUpdate;
