import React, { Fragment } from 'react';
import {
	Row,
	Col,
	Table,
	Button,
	Modal,
	Input,
	Descriptions,
	Space,
	message,
} from 'antd';
import { RouteComponentProps } from 'react-router-dom';
import {
	EyeOutlined,
	PlusOutlined,
	DeleteColumnOutlined,
} from '@ant-design/icons';
import { ColumnProps } from 'antd/lib/table';
import { FormItemProps } from 'antd/lib/form';
import { useProjectsList, useDeleteProject } from '../../services/project';
const { Search } = Input;
const details = [
	{
		label: '工程名称',
		name: 'name',
	},
	{
		label: '工程简介',
		name: 'desc',
	},
	{
		label: '项目类型',
		name: 'project_type',
	},
	{
		label: '工程造价(万)',
		name: 'price',
	},
	{
		label: '总建筑面积(㎡)',
		name: 'covered_area',
	},
	{
		label: '计划开工日期',
		name: 'start_day',
	},
	{
		label: '计划竣工日期',
		name: 'end_day',
	},
	{
		label: '项目功能',
		name: 'project_function',
	},
	{
		label: '总层数',
		name: 'total_level',
	},
	{
		label: '建筑层数',
		name: 'building_storey',
	},
	{
		label: '项目负责人',
		name: 'project_leader',
	},
	{
		label: '电话',
		name: 'phone',
	},
	{
		label: '安监备案号',
		name: 'safety_record_no',
	},
	{
		label: '施工单位',
		name: 'construction',
	},
	{
		label: '建筑单位',
		name: 'development',
	},
	{
		label: '监理单位',
		name: 'oversee',
	},
	{
		label: '设计单位',
		name: 'design',
	},
	{
		label: '勘察单位',
		name: 'exploration',
	},
	{
		label: '项目地址',
		name: 'location',
	},
];

const project: React.FC<RouteComponentProps> = ({ history }) => {
	const [searchState, setSearchState] = React.useState({
		page: 1,
		filter: '',
	});
	React.useEffect(() => {
		requestProjects({
			page: searchState.page,
			filter: searchState.filter,
		});
	}, [searchState.page, searchState.filter]);
	const [state, setState] = React.useState<{
		modalVisible: boolean;
		projectDetail?: any;
	}>({
		modalVisible: false,
		projectDetail: {},
	});
	const [projectsState, requestProjects] = useProjectsList();
	const [deleteState, requestDelete] = useDeleteProject();
	const columns: ColumnProps<any>[] = [
		{
			title: '项目名',
			key: 'name',
			dataIndex: 'name',
		},
		{
			title: '项目地址',
			key: 'location',
			dataIndex: 'location',
		},
		{
			title: '项目类型',
			key: 'category',
			dataIndex: 'category',
		},
		/*{
			title: '安监备案号',
			key: 'safety_record_no',
			dataIndex: 'safety_record_no',
		},*/
		{
			title: '项目经理',
			key: 'manager',
			dataIndex: 'manager',
		},
		{
			title: '项目经理电话',
			key: 'manager_phone',
			dataIndex: 'manager_phone',
		},
		{
			title: '创建时间',
			key: 'create_time',
			dataIndex: 'create_time',
		},
		{
			title: '状态',
			key: 'project_status',
			dataIndex: 'project_status',
		},
		{
			title: '操作',
			render: (record) => {
				return (
					<Space>
						<Button
							type='primary'
							href={`project/${record.id}`}
							icon={<EyeOutlined></EyeOutlined>}>
							查看
						</Button>
						<Button
							danger
							onClick={() => {
								Modal.confirm({
									title: '提示',
									content: `是否确认删除${record.name}项目`,
									okText: '确认',
									okButtonProps: {
										loading: deleteState.loading,
									},
									cancelText: '取消',
									onOk: () => {
										requestDelete({ id: record.id })
											.then(() => {
												message.success('删除项目成功', 1, () => {
													requestProjects(searchState);
												});
											})
											.catch((error) => {
												message.error(error.message);
											});
									},
								});
							}}
							icon={<DeleteColumnOutlined></DeleteColumnOutlined>}>
							删除
						</Button>
					</Space>
				);
			},
		},
	];

	const handleSwitchModalVisible = (projectDetail: {
		projectDetail?: object;
	}) => {
		setState((preState) => ({
			...preState,
			modalVisible: !preState.modalVisible,
			projectDetail: projectDetail.projectDetail,
		}));
	};
	const handleSearch = (value: string) => {
		setSearchState((preState) => ({ ...preState, page: 1, filter: value }));
	};
	return (
		<>
			<Row justify='end' gutter={[0, 30]}>
				<Col>
					<Button
						type='primary'
						icon={<PlusOutlined></PlusOutlined>}
						onClick={() => {
							history.push('project');
						}}>
						新增
					</Button>
				</Col>
			</Row>
			<Row gutter={[0, 24]}>
				<Col span={6}>
					<Search
						placeholder='项目名或安监备案号'
						onSearch={handleSearch}></Search>
				</Col>
			</Row>
			<Table
				rowKey={(record) => record.id}
				loading={projectsState.loading}
				dataSource={projectsState.dataSource}
				columns={columns}
				pagination={{
					hideOnSinglePage: true,
					total: projectsState.total,
					current: projectsState.page,
					onChange: (current) => {
						setSearchState((preState) => ({ ...preState, page: current }));
					},
				}}></Table>
		</>
	);
};
export default project;
