import * as React from 'react';
import {
	Form,
	Row,
	Col,
	Spin,
	Divider,
	Input,
	Cascader,
	Button,
	Space,
	message,
	Result,
} from 'antd';
import { FormItemProps } from 'antd/lib/form';

import Upload from '../../components/upload';
import Request from '../../utils/request';
import './index.scss';
const PhonepPattern = /^1[3456789]\d{9}$/;
const { Search } = Input;

const register: React.FC = () => {
	const [form] = Form.useForm();
	const [state, setState] = React.useState({
		loadingSend: false,
		loading: false,
		success: false,
		areaList: [],
	});
	React.useEffect(() => {
		Request.sendRequest({ url: '/v1/project/district' })
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					areaList: data.list,
				}));
			})
			.catch((error) => {});
	}, []);
	const handleSubmit = (data: any) => {
		if (state.loading) {
			return;
		}
		setState((preState) => ({
			...preState,
			loading: true,
		}));
		Request.sendRequest({
			url: '/v1/user/register',
			method: 'POST',
			data: {
				...data,
				business_license: data.business_license,
				province: data.area[0] || '',
				city: data.area[1],
				zone: data.area[2],
			},
		})
			.then(() => {
				setState((preState) => ({
					...preState,
					loading: false,
					success: true,
				}));
			})
			.catch((error) => {
				message.error(error.message);
				setState((preState) => ({ ...preState, loading: false }));
			});
	};
	const handlsSendCode = (phone: string) => {
		if (state.loadingSend) {
			return;
		}
		form
			.validateFields(['business_contact_phone'])
			.then(({ business_contact_phone }) => {
				setState((preState) => ({ ...preState, loadingSend: true }));
				Request.sendRequest({
					url: '/v1/vcode',
					params: {
						phone: business_contact_phone,
					},
				})
					.then(() => {
						message.success('验证码发送成功');
					})
					.catch((error) => {
						message.error(error.message);
					})
					.finally(() => {
						setState((preState) => ({
							...preState,
							loadingSend: false,
						}));
					});
			});
	};
	const formInputs: FormItemProps[] = [
		{
			label: '公司名称',
			name: 'name',
			required: true,
			children: <Input placeholder='请输入供应商名称'></Input>,
		},
		{
			label: '统一社会信用代码',
			name: 'social_code',
			required: true,
			children: <Input placeholder='请输入统一社会信用代码'></Input>,
		},
		{
			label: '法定代表人',
			name: 'legal_person',
			children: <Input placeholder='请输入法定代表人'></Input>,
		},
		{
			label: '身份证号',
			name: 'id_cert',
			children: <Input placeholder='请输入身份证号'></Input>,
		},
		{
			label: '地区',
			name: 'area',
			rules: [
				{
					required: true,
					message: '请选择企业地区',
				},
			],
			children: (
				<Cascader
					placeholder='请选择地区'
					fieldNames={{
						label: 'addr',
						value: 'addr',
						children: 'list',
					}}
					options={state.areaList}></Cascader>
			),
		},
		{
			label: '营业执照扫描件',
			name: 'business_license',
			children: <Upload limit={1}></Upload>,
			help: '上传正副本皆可，支持pdf,jpg,jpeg,png等格式',
			rules: [
				{
					required: true,
					message: '请上传营业执照扫描件',
				},
			],
		},

		{
			label: '用户名',
			name: 'user_name',
			children: <Input placeholder='请输入用户名'></Input>,
		},
		{
			label: '密码',
			name: 'passwd',
			children: <Input.Password placeholder='请输入密码'></Input.Password>,
		},
		{
			label: '确认密码',
			dependencies: ['passwd'],
			name: 'confirmpasswd',
			rules: [
				{
					required: true,
					message: '请输入确认密码',
				},
				({ getFieldValue }) => ({
					validator(rule, value) {
						if (!value || getFieldValue('passwd') === value) {
							return Promise.resolve();
						}
						return Promise.reject('密码输入不一致');
					},
				}),
			],
			children: <Input.Password placeholder='请确认密码'></Input.Password>,
		},
		{
			label: '业务联系人',
			name: 'business_contact',
			children: <Input placeholder='请输入业务联系人'></Input>,
		},
		{
			label: '业务联系人电话',
			name: 'business_contact_phone',
			rules: [
				{
					whitespace: true,
				},
				{
					required: true,
					message: '请输入业务联系人电话',
				},
				{
					pattern: PhonepPattern,
					message: '请输入正确的手机号',
				},
			],
			children: <Input placeholder='请输入业务联系人电话'></Input>,
		},
		{
			label: '业务负责人',
			name: 'business_responsible',
			children: <Input placeholder='请输入业务负责人'></Input>,
		},
		{
			label: '业务负责人电话',
			name: 'business_responsible_phone',
			rules: [
				{
					whitespace: true,
				},
				{
					required: true,
					message: '请输入业务负责人电话',
				},
				{
					pattern: PhonepPattern,
					message: '请输入正确的手机号',
				},
			],
			children: <Input placeholder='请输入业务负责人电话'></Input>,
		},
		{
			label: '应急联系人',
			name: 'emergency_contact',

			children: <Input placeholder='请输入应急联系人'></Input>,
		},
		{
			label: '应急联系人电话',
			name: 'emergency_contact_phone',
			rules: [
				{
					whitespace: true,
				},
				{
					required: true,
					message: '请输入应急联系人电话',
				},
				{
					pattern: PhonepPattern,
					message: '请输入正确的手机号',
				},
			],
			children: <Input placeholder='请输入应急联系人电话'></Input>,
		},
		{
			label: '验证码',
			name: 'verify',
			children: (
				<Search
					onSearch={handlsSendCode}
					loading={state.loadingSend}
					placeholder='请输入验证码'
					enterButton='发送验证码'></Search>
			),
		},
	];
	if (state.success) {
		return (
			<Result
				status='success'
				title='恭喜您提交资料成功'
				subTitle='Order number: 2017182818828182881 Cloud server configuration takes 1-5 minutes, please wait.'
				extra={[
					<Button
						type='primary'
						key='console'
						onClick={() => {
							history.back();
						}}>
						返回
					</Button>,
					<Button
						key='buy'
						onClick={() => {
							setState((preState) => ({
								...preState,
								success: false,
							}));
						}}>
						继续
					</Button>,
				]}
			/>
		);
	}
	return (
		<div className='register-layout'>
			<Divider>
				<h2>企业注册</h2>
			</Divider>
			<Spin spinning={state.loading}>
				<Form
					form={form}
					onFinish={handleSubmit}
					className='register-form'
					labelCol={{ span: 6 }}
					wrapperCol={{ span: 12 }}>
					<Row justify='center'>
						{formInputs.map((element) => {
							return (
								<Col key={element.name as string} span={13}>
									<Form.Item
										hasFeedback
										rules={[
											{
												required: true,
												message: `请输入${element.label}`,
											},
											{
												whitespace: true,
											},
										]}
										required
										colon
										{...element}></Form.Item>
								</Col>
							);
						})}
					</Row>
					<Row justify='center' gutter={[0, 30]}>
						<Col span={6}>
							<Space>
								<Button type='primary' size='large' htmlType='submit'>
									提交
								</Button>
								<Button
									size='large'
									htmlType='reset'
									onClick={() => (window.location.href = '/')}>
									返回
								</Button>
							</Space>
						</Col>
					</Row>
				</Form>
			</Spin>
		</div>
	);
};
export default register;
