import React, { Fragment } from 'react';
import { Table, Button, Modal, Row, Input, Col, Typography, Badge, Divider } from 'antd';
import { EyeOutlined, EyeInvisibleOutlined } from '@ant-design/icons';
import { ColumnProps } from 'antd/lib/table';
import { RouteComponentProps } from 'react-router-dom';
import {
	useVideoList,
	VideoStatus,
	VideoState,
	videoStateKeys,
	chanleState,
	useChanleList,
} from '../../services/video';
const { Search } = Input;
const { Text } = Typography;
const chanleColums: ColumnProps<any>[] = [
	{
		title: '通道号',
		dataIndex: 'name',
		key: 'name',
	},
	{
		title: '通道名',
		dataIndex: 'channel_no',
		key: 'channel_no',
	},
	{
		title: '状态',
		dataIndex: 'state',
		key: 'state',
		render: (indexKey) => {
			return (
				<Badge
					status={indexKey === 1 ? 'success' : 'error'}
					text={chanleState[indexKey as 0 | 1]}/>
			);
		},
	},
];

const videos: React.FC<RouteComponentProps> = ({ history }) => {
	const [VideoListState, requestVideoList] = useVideoList();
	const [searchState, setSearchState] = React.useState({
		page: 1,
		filter: '',
	});
	const [chanleListState, requestChanleList] = useChanleList();
	const [state, setState] = React.useState<{
		visibleModal: boolean;
		sn?: string;
	}>({
		visibleModal: false,
	});
	React.useEffect(() => {
		requestVideoList(searchState);
	}, [searchState]);
	const videoListColums: ColumnProps<any>[] = [
		{
			title: '项目名',
			dataIndex: 'project_name',
			key: 'project_name',
		},
		{
			title: '供应商',
			dataIndex: 'provider_name',
			key: 'provider_name',
		},
		{
			title: '设备名',
			dataIndex: 'name',
			key: 'name',
    },
    {
			title: '国标编号',
			dataIndex: 'sn',
			key: 'sn',
		},
		{
			title: '传输模式',
			dataIndex: 'media_transport',
			key: 'media_transport',
		},
		{
			title: '通道数',
			dataIndex: 'channel_count',
			key: 'channel_count',
		},
		{
			title: 'IP',
			dataIndex: 'ip',
			key: 'ip',
		},
		{
			title: '端口',
			dataIndex: 'port',
			key: 'port',
		},

		{
			title: '状态',
			dataIndex: 'state',
			key: 'state',
			render: (dataIndex: 0 | 1, record) => {
				const isOnline = videoStateKeys.onLine === dataIndex;
				return record.status === 1 ? (
					<Fragment>
						<Badge color={isOnline ? 'green' : 'red'}></Badge>
						<Text type={isOnline ? 'success' : 'secondary'}>
							{VideoState[dataIndex]}
						</Text>
					</Fragment>
				) : null;
			},
		},
		{
			title: '操作',
			render: (record) =>
				record.status === 1 ? (
					<Button
						type='primary'
						icon={<EyeOutlined></EyeOutlined>}
						onClick={() => handleTurnChanleModal({ sn: record.sn })}>
						查看通道
					</Button>
				) : null,
		},
	];

	const handleTurnChanleModal = (parmas: { sn?: string }) => {
		setState((preState) => ({
			...preState,
			visibleModal: !preState.visibleModal,
			sn: parmas.sn,
		}));
	};
	const handleSearch = (value: string) => {
		setSearchState((preState) => ({ ...preState, page: 1, filter: value }));
	};
	React.useEffect(() => {
		if (state.sn) {
			requestChanleList({ sn: state.sn, page: 1 });
		}
	}, [state.sn]);

	return (
		<React.Fragment>
			<Row gutter={[0, 24]}>
				<Col span={6}>
					<Search
						placeholder='设备唯一编码，项目名或安监备案号'
						onSearch={handleSearch}/>
				</Col>
			</Row>
      <Divider/>
			<Table
				rowKey={(record) => record.id}
				pagination={{
					hideOnSinglePage: true,
					total: VideoListState.total,
					current: VideoListState.page,
					onChange: (current) => {
						setSearchState((preState) => ({ ...preState, page: current }));
					},
				}}
				columns={videoListColums}
				dataSource={VideoListState.dataSource}
				loading={VideoListState.loading}/>
			<Modal
				width={600}
				title='通道列表'
				visible={state.visibleModal}
				footer={null}
				onCancel={() => handleTurnChanleModal({})}>
				<Table
					rowKey={(record) => record.id}
					loading={chanleListState.loading}
					columns={chanleColums}
					pagination={{
						hideOnSinglePage: true,
						showSizeChanger: false,
						current: chanleListState.page,
						onChange: (page) =>
							requestChanleList({ sn: state.sn as string, page }),
						total: chanleListState.total,
					}}
					dataSource={chanleListState.dataSource}/>
			</Modal>
		</React.Fragment>
	);
};
export default videos;
