import * as React from 'react';
import Request from '../utils/request';
export enum AccountEnable {
	'启用',
	'停用',
}
export const AccoutTypes = {
	1: '建设单位',
	2: '项目部',
	3: '监理部',
};
/**
 *
 * @description 获取账号列表
 */
export const useAccountList = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		dataSource: any[];
		total: number;
		page: number;
		error?: { code: number; message: string };
	}>({
		loading: false,
		dataSource: [],
		total: 0,
		page: 1,
	});
	const request = (params: { page: number; filter?: String }) => {
		setState((preState) => ({ ...preState, loading: true, error: undefined }));
		return Request.sendRequest({
			url: '/v1/project/user_list',
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					...data,
					dataSource: data.list.map((element: any, index: number) => {
						return {
							...element,
							index: index + 1,
							enable: Number(element.enable),
						};
					}),
				}));
			})
			.catch((error) => {
				setState((preState) => ({
					...preState,
					loading: false,
					error: error,
				}));
			});
	};

	return [state, request] as const;
};
/**
 *
 * @description 获取账号列表
 */
export const useUpdateAccountStatus = () => {
	const [state, setState] = React.useState({
		loading: false,
	});
	const request = (data: { enable: Boolean; id: String }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/project/user',
			method: 'PUT',
			data,
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return [state, request] as const;
};
