import * as React from 'react';
import Request from '../utils/request';
export const useUserLogin = () => {
  const [state, setState] = React.useState({ loading: false });

  const request = (data: {
    captcha: number;
    password: string;
    user: string;
  }) => {
    setState((preState) => ({ ...preState, loading: true }));
    return new Promise((resolve, reject) => {
      Request.sendRequest({
        url: '/v1/user/login',
        method: 'POST',
        data: data,
      })
        .then((data: any) => {
          localStorage.setItem('token', data.token);
          localStorage.setItem('refresh_token', data.refresh_token);

          resolve(data);
        })
        .catch((error) => {
          reject(error);
        })
        .finally(() => {
          setState((preState) => ({ ...preState, loading: false }));
        });
    });
  };
  return [state, request] as const;
};
/**
 * @description 获取图片验证码ID
 */
export const useCaptchaId = () => {
  const [state, setState] = React.useState({
    loading: false,
    data: {
      capture_id: '',
    },
  });
  const request = () => {
    setState((preState) => ({ ...preState, loading: true }));
    return new Promise((resolve, reject) => {
      Request.sendRequest({
        url: '/v1/user/captcha_id',
      })
        .then((data: any) => {
          setState((preState) => ({
            ...preState,
            data: {
              ...preState.data,
              capture_id: data.CaptureId || data.capture_id,
            },
          }));
          resolve(data);
        })
        .catch((error) => {
          reject(error);
        })
        .finally(() => {
          setState((preState) => ({ ...preState, loading: false }));
        });
    });
  };
  return [state, request] as const;
};
export const useSendCode = () => {
  const [state, setState] = React.useState({
      loading: false,
  })
  const request = async (params: { phone: string }) => {
      setState((preState) => ({ ...preState, loading: true }))
      await Request.sendRequest({
          url: '/v1/vcode',
          params,
      }).finally(() => {
          setState((preState) => ({ ...preState, loading: false }))
      })
  }
  return { state, request } as const
}
export const useChangePassWord = () => {
  const [state, setState] = React.useState({
      loading: false,
  })
  const request = async (data: {
      passwd: string
      phone: string
      vcode: number
  }) => {
      setState((preState) => ({ ...preState, loading: true }))
      await Request.sendRequest({
          url: '/v1/user/set_passwd',
          method: 'PUT',
          data,
      }).finally(() => {
          setState((preState) => ({ ...preState, loading: false }))
      })
  }
  return { state, request } as const
}
export const useQueryUser = () => {
  const [state, setState] = React.useState<{
    loading: boolean;
    data?: { status: number; feedback: string };
    error: null | { code: number; message: string };
  }>({
    loading: false,

    error: null,
  });
  const request = (params: { social_code: string }) => {
    return new Promise((resolve, reject) => {
      setState((preState) => ({ ...preState, loading: true, data: undefined }));
      return Request.sendRequest({
        url: '/v1/user/status',
        params,
      })
        .then((data: any) => {
          setState((preState) => ({ ...preState, loading: false, data }));
          resolve(data);
        })
        .catch((error) => {
          setState((preState) => ({
            ...preState,
            loading: false,
            error: error,
          }));
          reject(error);
        });
    });
  };
  return { state, request } as const;
};
/**
 * @description 修改邮箱
 */
export const useChangeEmail = () => {
  const [state, setState] = React.useState({
    loading: false,
  });
  const request = (data: { email: string; password: string }) => {
    return Request.sendRequest({
      url: '/v1/user/verify_mail',
      method: 'PUT',
      data,
    }).finally(() => {
      setState((preState) => ({ ...preState, loading: false }));
    });
  };
  return { state, request } as const;
};
/**
 * @description 发送验证码
 */
export const useSendPhoneCode = () => {
  const [state, setState] = React.useState({
    loading: false,
  });
  const request = (params: { phone: string }) => {
    return Request.sendRequest({
      url: '/v1/vcode',
      params,
    }).finally(() => {
      setState((preState) => ({ ...preState, loading: false }));
    });
  };
  return { state, request } as const;
};
/**
 * @description 修改手机号
 */
export const useChangePhone = () => {
  const [state, setState] = React.useState({
    loading: false,
  });
  const request = (data: { phone: string; vcode: number }) => {
    return Request.sendRequest({
      url: '/v1/user/phone',
      method:"PUT",
      data,
    }).finally(() => {
      setState((preState) => ({ ...preState, loading: false }));
    });
  };
  return { state, request } as const;
};
/**
 * @description 获取用户信息
 */
export const useGetUrerInfo=()=>{
  const [state, setState] = React.useState({
    loading: false,
    data:{email:"",phone:""},
    error:null
  });
  const request=()=>{
    setState(preState=>({...preState,loading:true}))
    Request.sendRequest({
      url:"/v1/user/info"
    }).then((data:any)=>{
      setState(preState=>({...preState,loading:false,data}))
    }).catch(error=>{
      setState(preState=>({...preState,loading:false,error}))
    })
  }
  return {state,request} as const
}
/**
 * @description 重置用户密码
 */
export const useChangePassword =()=>{
  const [state, setState] = React.useState({
    loading: false,
  });
  const request=(data:{new:string;old:string})=>{
    setState(preState=>({...preState,loading:true}))
   return Request.sendRequest({
      url:"/v1/user/change_passwd",
      data,
      method:"PUT"
    }).then((data:any)=>{
      setState(preState=>({...preState,loading:false,data}))
    }).catch(error=>{
      setState(preState=>({...preState,loading:false,error}))
    })
  }
  return {state,request} as const
}